powered by
Compute scagnostics on all possible scatter plots for the given data
calc_scags_wide( all_data, scags = c("outlying", "stringy", "striated", "striated2", "clumpy", "clumpy2", "sparse", "skewed", "convex", "skinny", "monotonic", "splines", "dcor"), out.rm = TRUE, euclid = FALSE )
A data frame that gives the data's scagnostic scores for each possible variable combination.
tibble of multivariate data on which to compute scagnostics
collection of strings matching names of scagnostics to calculate: outlying, stringy, striated, striated2, striped, clumpy, clumpy2, sparse, skewed, convex, skinny, monotonic, splines, dcor
logical indicator to indicate if outliers should be removed before calculating non outlying measures
logical indicator to use Euclidean distance
calc_scags
# Calculate selected scagnostics data(pk) calc_scags_wide(pk[,2:5], scags=c("outlying","monotonic"))
Run the code above in your browser using DataLab