Learn R Programming

cassowaryr (version 2.0.2)

draw_mst: Drawing the MST

Description

This function will draw the MST for a scatterplot.

Usage

draw_mst(x, y, alpha = 0.5, out.rm = TRUE)

Value

A "gg" object that draws the plot's MST.

Arguments

x

numeric vector

y

numeric vector

alpha

The alpha value used to build the graph object. Larger values allow points further apart to be connected.

out.rm

option to return the outlier removed MST

Examples

Run this code
require(dplyr)
require(ggplot2)
data("features")
nl <- features %>% filter(feature == "nonlinear2")
draw_mst(nl$x, nl$y)

Run the code above in your browser using DataLab