Learn R Programming

cassowaryr (version 2.0.2)

scree: Pre-processing to generate scagnostic measures

Description

Pre-processing to generate scagnostic measures

Usage

scree(x, y, binner = NULL, ...)

Value

An object of class "scree" that consists of three elements:

  • del: the Delauney-Voronoi tesselation from alphahull::delvor()

  • weights: the lengths of each edge in the Delauney triangulation

  • alpha: the radius or alpha value that will be used to generate the alphahull

Arguments

x, y

numeric vectors

binner

an optional function that bins the x and y vectors prior to triangulation

...

other args

Examples

Run this code

x <- runif(100)
y <- runif(100)
scree(x,y)

Run the code above in your browser using DataLab