powered by
Pre-processing to generate scagnostic measures
scree(x, y, binner = NULL, ...)
An object of class "scree" that consists of three elements:
del: the Delauney-Voronoi tesselation from alphahull::delvor()
del
alphahull::delvor()
weights: the lengths of each edge in the Delauney triangulation
weights
alpha: the radius or alpha value that will be used to generate the alphahull
alpha
numeric vectors
an optional function that bins the x and y vectors prior to triangulation
other args
x <- runif(100) y <- runif(100) scree(x,y)
Run the code above in your browser using DataLab